| Title: | Utilities for Standardized Statistical Data Set for Education |
|---|---|
| Description: | More about what it does (maybe more than one line) Use four spaces when indenting paragraphs within the Description. |
| Authors: | Shinya Uryu [aut, cre] (ORCID: <https://orcid.org/0000-0002-0493-6186>) |
| Maintainer: | Shinya Uryu <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-06-09 07:39:15 UTC |
| Source: | https://github.com/uribo/ssdse |
Read specific SSDSE data file
read_ssdse_a(path, lang, pack = TRUE, ...) read_ssdse_b(path, lang, pack = TRUE, ...) read_ssdse_c(path, lang, ...) read_ssdse_d(path, lang, ...) read_ssdse_e(path, version = 2, lang, ...)read_ssdse_a(path, lang, pack = TRUE, ...) read_ssdse_b(path, lang, pack = TRUE, ...) read_ssdse_c(path, lang, ...) read_ssdse_d(path, lang, ...) read_ssdse_e(path, version = 2, lang, ...)
path |
path to file |
lang |
column name language |
pack |
packing for common variables |
... |
not use |
version |
file version |